==> photovoltaic_modeling_python-0.1.0.tar.gz: photovoltaic_modeling_python-0.1.0/setup.py <==
"""A setuptools based setup module.
Based on:
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

# Get the long description from the README file
readme_file = path.join(path.dirname(__file__), 'README.md')
# When installing locally, the file is not found:
if path.isfile(readme_file):
    with open(readme_file, encoding='utf-8') as f:
        long_description = f.read()
else:
    long_description = 'Get the parameters that are not available in the datasheet of photovoltaic modules.'

# TODO: Modify to use one of the techniques described in https://packaging.python.org/en/latest/single_source_version.html
# imports __version__ into the local namespace
version_file = path.join(path.dirname(__file__), 'photovoltaic_modeling/version.py')
with open(version_file, 'r') as f:
    exec(f.read())

setup(
    name='photovoltaic_modeling_python',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    # version='1.2.0',
    version=__version__,

    description='Get the parameters that are not available in the datasheet of photovoltaic modules.',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/tadatoshi/photovoltaic_modeling_python',

    # Author details
    author='Tadatoshi Takahashi',
    author_email='tadatoshi@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Scientific/Engineering',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # TODO: Verify if the code works with Python 2.6 and 2.7.
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        # 'Programming Language :: Python :: 2',
        # 'Programming Language :: Python :: 2.6',
        # 'Programming Language :: Python :: 2.7',
        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.2',
        # 'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='control optimization engineering',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    # packages=find_packages(exclude=['tests']),
    packages=['photovoltaic_modeling', 'tests.photovoltaic_modeling', 'photovoltaic_modeling.examples'], 

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    # install_requires=['peppercorn'],
    install_requires=['numpy', 'scipy'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'sample': ['package_data.dat'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
    entry_points={
        'console_scripts': [
            'photovoltaic_modeling=photovoltaic_modeling.command_line:main',
        ],
    },
)

==> photovoltaic_modeling_python-0.2.0.tar.gz: photovoltaic_modeling_python-0.2.0/setup.py <==
"""A setuptools based setup module.
Based on:
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

# Get the long description from the README file
readme_file = path.join(path.dirname(__file__), 'README.md')
# When installing locally, the file is not found:
if path.isfile(readme_file):
    with open(readme_file, encoding='utf-8') as f:
        long_description = f.read()
else:
    long_description = 'Get the parameters that are not available in the datasheet of photovoltaic modules.'

# TODO: Modify to use one of the techniques described in https://packaging.python.org/en/latest/single_source_version.html
# imports __version__ into the local namespace
version_file = path.join(path.dirname(__file__), 'photovoltaic_modeling/version.py')
with open(version_file, 'r') as f:
    exec(f.read())

setup(
    name='photovoltaic_modeling_python',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    # version='1.2.0',
    version=__version__,

    description='Get the parameters that are not available in the datasheet of photovoltaic modules.',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/tadatoshi/photovoltaic_modeling_python',

    # Author details
    author='Tadatoshi Takahashi',
    author_email='tadatoshi@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Scientific/Engineering',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # TODO: Verify if the code works with Python 2.6 and 2.7.
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        # 'Programming Language :: Python :: 2',
        # 'Programming Language :: Python :: 2.6',
        # 'Programming Language :: Python :: 2.7',
        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.2',
        # 'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='control optimization engineering',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    # packages=find_packages(exclude=['tests']),
    packages=['photovoltaic_modeling', 'tests.photovoltaic_modeling', 
              'photovoltaic_modeling.parameter', 'tests.photovoltaic_modeling.parameter', 
              'photovoltaic_modeling.diode_model', 'tests.photovoltaic_modeling.diode_model', 
              'photovoltaic_modeling.examples', 
              'photovoltaic_modeling.examples.parameter', 
              'photovoltaic_modeling.examples.diode_model.single_diode_model'], 

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    # install_requires=['peppercorn'],
    install_requires=['numpy', 'scipy'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'sample': ['package_data.dat'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
    entry_points={
        'console_scripts': [
            'photovoltaic_modeling=photovoltaic_modeling.command_line:main',
        ],
    },
)
